window.onload = function() {
  
  String.prototype.toHHMMSS = function () {
    var sec_num = parseInt(this, 10); // don't forget the second param
    var hours   = Math.floor(sec_num / 3600);
    var minutes = Math.floor((sec_num - (hours * 3600)) / 60);
    var seconds = sec_num - (hours * 3600) - (minutes * 60);

    if (hours   < 10) {
	  var time = '0'+hours+':'+minutes+':'+seconds;
	}
    if (minutes < 10) {
	  var time    = '0'+minutes+':'+seconds;
	}
    if (seconds < 10) {
	  var time = minutes+':0'+seconds;;
	}
    return time;
  }

  // Video layout
  var videocontainer = document.getElementById("video-container");
  var videocontrols = document.getElementById("video-controls");
	
  // Timer
  var timer = document.getElementById("timer");
	
  // Video
  var video = document.getElementById("video");

  // Buttons
  var playButton = document.getElementById("play-pause");
  var muteButton = document.getElementById("mute");
  var fullScreenButton = document.getElementById("full-screen");
  
  // Sliders
  var seekbar = document.getElementById("seek-bar");
  var volumeBar = document.getElementById("volume-bar");

  var doc = window.document;
  
  seekbar.width  = $(window).width();
  
  video.width  = $(window).width();
  
  if(!doc.fullscreenElement && !doc.mozFullScreenElement && !doc.webkitFullscreenElement && !doc.msFullscreenElement) {
	video.height  = $(window).height()-42;
  } 
  else  {
	video.height  = $(window).height();
  }
  
  $(window).resize(function() {
    seekbar.width  = $(window).width();
	video.width  = $(window).width();
	if(!doc.fullscreenElement && !doc.mozFullScreenElement && !doc.webkitFullscreenElement && !doc.msFullscreenElement) {
	  video.height  = $(window).height()-42;
	} 
	else  {
	  video.height  = $(window).height();
	}
  });
  
  var ctx = seekbar.getContext("2d");

  seekbar.onclick = function (e) {
    var duration = video.duration;
    var width = seekbar.width;
    var x = e.clientX - 5;

    video.currentTime = x / width * duration;
  };
  
  video.addEventListener("click", function() {
    if (video.paused === true) {
      // Play the video
      video.play();

      // Update the button text to 'Pause'
      playButton.className = "pause";
	} 
    else {
      // Pause the video
      video.pause();

      // Update the button text to 'Play'
      playButton.className = "play";
	}
  });

  video.addEventListener("ended", function() {
   		// Pause the video
		video.pause();
			
		// Update the button text to 'Restart'
		playButton.className = "restart";
	});
	
	// Event listener for the play/pause button
	playButton.addEventListener("click", function() {
		if (video.paused == true) {
			// Play the video
			video.play();

			// Update the button text to 'Pause'
			playButton.className = "pause";
		} else {
			// Pause the video
			video.pause();

			// Update the button text to 'Play'
			playButton.className = "play";
		}
	});


	// Event listener for the mute button
	muteButton.addEventListener("click", function() {
		if (video.muted == false) {
			// Mute the video
			video.muted = true;

			// Update the button text
			muteButton.className = "mute";
		} else {
			// Unmute the video
			video.muted = false;

			// Update the button text
			if(volumeBar.value < 50) {
	          muteButton.className = "sound_down";
			}
			else {
	  		  muteButton.className = "sound_up";
			}
		}
	});


	// Event listener for the full-screen button
	fullScreenButton.addEventListener("click", function() {
		var doc = window.document;

  		if(!doc.fullscreenElement && !doc.mozFullScreenElement && !doc.webkitFullscreenElement && !doc.msFullscreenElement) {
			if (videocontainer.requestFullscreen) {
    			videocontainer.requestFullscreen();
			}
			else if (videocontainer.mozRequestFullScreen) {
    			videocontainer.mozRequestFullScreen();
			}
			else if (videocontainer.webkitRequestFullScreen) {
    			videocontainer.webkitRequestFullScreen();
			}
			else if (videocontainer.msRequestFullscreen) {
    			videocontainer.msRequestFullscreen();
			}

  		}
  		else {
    		if (document.exitFullscreen) {
    			document.exitFullscreen();
			}
			else if (document.mozCancelFullScreen) {
    			document.mozCancelFullScreen();
			}
			else if (document.webkitCancelFullScreen) {
    			document.webkitCancelFullScreen();
			}
			else if (document.msExitFullscreen) {
    			document.msExitFullscreen();
			}

  		}
	});
	
  video.addEventListener("timeupdate", function() {
    
	if (video.paused == true) {
	  // Update the button text to 'Play'
	  playButton.className = "play";
	}
	else {
	  // Update the button text to 'Pause'
	  playButton.className = "pause";
	}
		
    var buffered = video.buffered;
    var lenght = buffered.length;
    var width = seekbar.width;
    var height = seekbar.height;
    var duration = video.duration;
    var x1;
	var x2;
	
	// Update the slider value buffer
    ctx.fillStyle = '#999';

    while (lenght--) {
      x1 = buffered.start(lenght) / duration * width;
      x2 = buffered.end(lenght) / duration * width;
      ctx.fillRect(x1, 0, x2 - x1, height);
    }
	
	// Update the slider value played bar
    x1 = video.currentTime / duration * width;
	
	ctx.fillStyle = '#d00';
    ctx.fillRect(0, 0, x1, height);
	
	// Update the slider value played circle
    ctx.fillStyle = '#fff';
	
    ctx.beginPath();
    ctx.arc(x1, height * 0.5, 5, 0, 2 * Math.PI);
    ctx.fill();
	
	// time update duration
	timer.innerHTML = video.currentTime.toFixed(0).toHHMMSS()+' / '+video.duration.toFixed(0).toHHMMSS();
  });
  
  // Event listener for the volume bar
  volumeBar.addEventListener("change", function() {
  	if (video.muted == false) {
	  if(volumeBar.value < 50) {
	    muteButton.className = "sound_down";
	  }
	  else {
	    muteButton.className = "sound_up";
	  }
	} else {
	  muteButton.className = "mute";
	}
	// Update the video volume
	video.volume = volumeBar.value / 100;
  });
};